package org.jtheque.films.stats;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.feature.Feature;
import org.jtheque.core.managers.feature.IFeatureManager;
import org.jtheque.core.managers.feature.IFeatureManager.CoreFeature;
import org.jtheque.core.managers.feature.Feature.FeatureType;
import org.jtheque.core.managers.module.annotations.ModuleDefinition;
import org.jtheque.core.managers.module.annotations.Module;
import org.jtheque.core.managers.module.annotations.PrePlug;
import org.jtheque.core.managers.module.annotations.Plug;
import org.jtheque.core.managers.module.annotations.UnPlug;

/**
 * A JTheque Module to display stats of films, actors and realizers.
 *
 * @author Baptiste Wicht
 */
@Module(name = "JTheque Stats Module", author = "Baptiste Wicht", description = "Affiche des statistiques sur les films", 
    version = "1.4", coreVersion = "2.0.1", jarFile = "jtheque-stats-module-1.4.jar")
@ModuleDefinition(
        dependency = "JTheque Films Module",
        updateURL = "http://jtheque.developpez.com/public/versions/StatsModule.versions")
public final class StatsModule {
    /**
     * The basename for the images.
     */
    public static final String IMAGE_BASENAME = "org/jtheque/films/stats/ressources/images";
    private static final String BASENAME = "org.jtheque.films.stats.ressources.i18n.stats";

    /**
     * The feature for displaying the stats.
     */
    private Feature statsFeature;

    @PrePlug
    public static void prePlug() {
        Managers.getManager(ILanguageManager.class).addBasename(BASENAME);
    }

    @Plug
    public void plug() {
        IFeatureManager manager = Managers.getManager(IFeatureManager.class);
        
        statsFeature = manager.addSubFeature(manager.getFeature(CoreFeature.ADVANCED), 
                "displayStatsAction", FeatureType.SEPARATED_ACTION, 2, StatsModule.IMAGE_BASENAME, "stats");
    }

    @UnPlug
    public void unplug() {
        Managers.getManager(ILanguageManager.class).removeBasename(BASENAME);

        Managers.getManager(IFeatureManager.class).getFeature(CoreFeature.ADVANCED).removeSubFeature(statsFeature);
    }
}