package org.jtheque.films.stats.view.impl.panels;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdesktop.swingx.JXHeader;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.ui.RectangleAnchor;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.resource.IResourceManager;
import org.jtheque.core.managers.resource.ImageType;
import org.jtheque.core.managers.language.Internationalizable;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.films.stats.StatsModule;
import org.jtheque.films.stats.services.able.IStatsService;
import org.jtheque.utils.ui.GridBagUtils;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JPanel;
import java.awt.Color;
import java.awt.Component;

/**
 * A stats panel for films.
 *
 * @author Baptiste Wicht
 */
public final class JPanelStatsFilms extends JPanel implements PanelStats, Internationalizable {
    private static final long serialVersionUID = 3556875889469725943L;

    @Resource
    private IStatsService statsService;

    /* Instances */
    private final ILanguageManager resources = Managers.getManager(ILanguageManager.class);

    private JXHeader header;

    private JFreeChart pieFilmsByType;
    private JFreeChart pieFilmsByKind;
    private JFreeChart pieFilmsByNote;

    /**
     * Build the panel.
     */
    @PostConstruct
    private void build() {
        Managers.getManager(ILanguageManager.class).addInternationalizable(this);
        
        PanelBuilder builder = new PanelBuilder(this);

        header = new JXHeader();
        header.setTitle(resources.getMessage("stats.films.title"));
        header.setDescription(statsService.getTitles()[2]);
        header.setIcon(Managers.getManager(IResourceManager.class).getIcon(
                StatsModule.IMAGE_BASENAME, "stats-big", ImageType.JPG));

        builder.add(header, builder.gbcSet(0, 0));

        pieFilmsByType = ChartFactory.createPieChart3D(resources.getMessage("stats.films.pie.type"),
                statsService.getInformations().getStatsOfFilmByType(), true, true, true);

        pieFilmsByType.getLegend().setLegendItemGraphicLocation(RectangleAnchor.RIGHT);

        Component panelPieFilmsByType = new ChartPanel(pieFilmsByType);
        panelPieFilmsByType.setBackground(Color.white);

        builder.add(panelPieFilmsByType, builder.gbcSet(0, 1, GridBagUtils.BOTH, GridBagUtils.BASELINE, 1.0, 0.33));

        pieFilmsByKind = ChartFactory.createPieChart3D(resources.getMessage("stats.films.pie.kind"),
                statsService.getInformations().getStatsOfFilmByKind(), true, true, true);

        pieFilmsByKind.getLegend().setLegendItemGraphicLocation(RectangleAnchor.RIGHT);

        Component panelPieFilmsByKind = new ChartPanel(pieFilmsByKind);
        panelPieFilmsByKind.setBackground(Color.white);

        builder.add(panelPieFilmsByKind, builder.gbcSet(0, 2, GridBagUtils.BOTH, GridBagUtils.BASELINE, 1.0, 0.33));

        pieFilmsByNote = ChartFactory.createPieChart3D(resources.getMessage("stats.films.pie.note"),
                statsService.getInformations().getStatsOfFilmByNote(), true, true, true);

        pieFilmsByNote.getLegend().setLegendItemGraphicLocation(RectangleAnchor.RIGHT);

        Component panelPieFilmsByNote = new ChartPanel(pieFilmsByNote);
        panelPieFilmsByNote.setBackground(Color.white);

        builder.add(panelPieFilmsByNote, builder.gbcSet(0, 3, GridBagUtils.BOTH, GridBagUtils.BASELINE, 1.0, 0.33));
    }

    @Override
    public void refreshText() {
        header.setTitle(resources.getMessage("stats.films.title"));
        header.setDescription(statsService.getInformations().getNumberOfFilms() + " " +
                resources.getMessage("stats.films.films").toLowerCase(resources.getCurrentLocale()));

        pieFilmsByType.setTitle(resources.getMessage("stats.films.pie.type"));
        pieFilmsByKind.setTitle(resources.getMessage("stats.films.pie.kind"));
        pieFilmsByNote.setTitle(resources.getMessage("stats.films.pie.note"));
    }

    /**
     * Return the header of the panel.
     *
     * @return The header of the panel.
     */
    public JXHeader getHeader() {
        return header;
    }
}